<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" version="1.0">
	<!--
	This file belongs to XMLReleaseNotes V0.6.6.
	-->
	<xsl:output method="html" indent="yes"/>
	<!--
	A boolean flag that tells whether a full stand-alone HTML page should be rendered, or just the body inner content.
	-->
	<xsl:param name="standAloneHTML" select="'yes'"/>
	<!--
	Defines the stylesheet URI that will be used by the generated HTML page. If not defined or empty, no external stylesheet will be used.
	-->
	<xsl:param name="CSS" select="'stylesheet.css'"/>
	<!--
	Defines the content of the additional stylesheet code that will be inlined within the generated HTML page, provided not null, nor empty.
	-->
	<xsl:param name="CSSContent"/>
	<!--
	Enables to define an abstract concerning the generated release notes, which will appear at the top. This abstract can be written under the HTML format.
	-->
	<xsl:param name="abstract"/>
	<!--
	Enables to define the first version of the release notes from which the documentation must be generated.
	-->
	<xsl:param name="firstVersion"/>
	<!--
	The last version the documentation must be generated for.
	-->
	<xsl:param name="lastVersion"/>
	<!--
	This enables to filter the items that should be documented (by defaults, all items are documented). Possible values are 'func' or 'tech', i.e. the possible values for the 'func' attribute of the 'Feature' XML element in the XML release notes file.
	-->
	<xsl:param name="typeFilter"/>
	<!--
	The minimum value of the XML 'Feature' 'importance' attribute, in order to be rendered.
	-->
	<xsl:param name="importanceThreshold" select="'4'"/>
	<!--
	This indicates whether the delivery information should be printed or not. Usefull when you do not want to propose some downloading of the artifacts.
	-->
	<xsl:param name="delivery" select="'true'"/>
	<!--
	This indicates whether the composition information should be printed or not.
	-->
	<xsl:param name="composition" select="'true'"/>
	<!--
	This indicates whether the dependencies information should be printed or not.
	-->
	<xsl:param name="dependency" select="'true'"/>
	<!--
	This indicates whether the requirements information should be printed or not.
	-->
	<xsl:param name="requirement" select="'true'"/>
	<!--
	This indicates whether the delivery should contain the advertizing banner at the bottom of the generated HTML stuff.
	-->
	<xsl:param name="banner" select="'true'"/>
	<!--
	The version of the XMLReleaseNotes framework.
	-->
	<xsl:variable name="_version" select="'0.6.6'"/>
	<!--
	A computed variable that tells how many columns we have.
	-->
	<xsl:variable name="_columnNumber">
		<xsl:choose>
			<xsl:when test="$delivery">3</xsl:when>
			<xsl:otherwise>2</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!--
	A computed variable related to the versions to be documented: see template '_printFirstVersionIndex'.
	-->
	<xsl:variable name="first_version_index">
		<xsl:for-each select="xrn:ReleaseNotes/Releases[1]">
			<xsl:call-template name="_printFirstVersionIndex"/>
		</xsl:for-each>
	</xsl:variable>
	<!--
	A computed variable related to the versions to be documented: see template '_printFirstVersionIndex'.
	-->
	<xsl:variable name="last_version_index">
		<xsl:for-each select="xrn:ReleaseNotes/Releases[1]">
			<xsl:call-template name="_printLastVersionIndex"/>
		</xsl:for-each>
	</xsl:variable>
	<xsl:template match="xrn:ReleaseNotes">
		<xsl:if test="@version != $_version">
			<xsl:message>Warning: the XML release notes version is '<xsl:value-of select="@version"/>' whereas the current XMLReleaseNotes framework used is '<xsl:value-of select="$_version"/>'; there may be incompatibily issues...</xsl:message>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$standAloneHTML = 'true'">
				<html>
					<head>
						<title>
							<xsl:text>Release Notes of </xsl:text>
							<xsl:value-of select="@ID"/>
						</title>
						<meta name="Author" content="XMLReleaseNotes"/>
						<xsl:if test="$CSS != ''">
							<link rel="StyleSheet" type="text/css" media="all">
								<xsl:attribute name="href"><xsl:value-of select="$CSS"/></xsl:attribute>
							</link>
						</xsl:if>
						<xsl:if test="$CSSContent != ''">
							<style type="text/css" media="all">
								<xsl:copy-of select="$CSSContent"/>
							</style>
						</xsl:if>
					</head>
					<body>
						<xsl:call-template name="_print"/>
					</body>
				</html>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_print"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="_print">
		<table class="releases" cellspacing="0" cellpadding="10">
			<thead>
				<tr>
					<td colspan="{$_columnNumber}">
						<xsl:choose>
							<xsl:when test="$abstract">
								<p>
									<xsl:value-of select="$abstract" disable-output-escaping="yes"/>
								</p>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>The following table shows the history of </xsl:text>
								<b>
									<xsl:value-of select="@ID"/>
								</b>
								<xsl:text> release notes.</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</thead>
			<tbody>
				<xsl:apply-templates select="Releases"/>
			</tbody>
			<xsl:if test="$banner = 'true'">
				<tfoot>
					<tr>
						<td colspan="{$_columnNumber}" class="copyright">
							<xsl:text>Release notes generated by </xsl:text>
							<strong>
								<i>
									<a href="http://xmlreleasenotes.free.fr" target="_blank">XMLReleaseNotes</a>
								</i>
							</strong>
							<xsl:text> V</xsl:text>
							<xsl:value-of select="$_version"/>
						</td>
					</tr>
				</tfoot>
			</xsl:if>
		</table>
		<br/>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases">
		<!--xsl:if test="string-length(first_version_index) = 0">
			<xsl:message>Warning, the 'firstVersion' parameter set to '<xsl:value-of select="$firstVersion"/>' seems to be incorrect!</xsl:message>
		</xsl:if>
		<xsl:if test="not(last_version_index)">
			<xsl:message>Warning, the 'lastVersion' parameter set to '<xsl:value-of select="$lastVersion"/>' seems to be incorrect!</xsl:message>
		</xsl:if-->
		<xsl:for-each select="Release">
			<xsl:if test="position() &lt;= $first_version_index and position() &gt;= $last_version_index">
				<tr>
					<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">even</xsl:when><xsl:otherwise>odd</xsl:otherwise></xsl:choose></xsl:attribute>
					<td>
						<xsl:call-template name="_printReleaseVersion"/>
						<xsl:call-template name="_printReleaseContent"/>
						<xsl:if test="$delivery = 'true'">
							<xsl:call-template name="_printReleaseDelivery"/>
						</xsl:if>
					</td>
				</tr>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<!--
	Warning, the '_printComposition', '_printRequirements' and '_printDependencies' are the same templates, as far as the logic and layout are concerned. They only differ by the XML element they handle. Should think of a way to collapse them into a single template...
	The current node should be a 'Release' XML element.
	-->
	<xsl:template name="_printComposition">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Composition">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Composition) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Composition) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Composition/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Composition/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Composition">
			<br/>
			<table class="composition">
				<thead>
					<tr>
						<th>
							<i>
								<font size="-1">Composition</font>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Composition/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Composition/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Composition/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Composition/Component[@ID = current()/@ID]) = 0">
									<tr>
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:value-of select="@ID"/>
											<xsl:text>&#160;</xsl:text>
											<xsl:value-of select="@version"/>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printRequirements">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Requirements">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Requirements) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Requirements) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Requirements/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Requirements/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Requirements">
			<br/>
			<table class="requirement">
				<thead>
					<tr>
						<th>
							<i>
								<font size="-1">Requirements</font>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Requirements/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Requirements/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Requirements/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Requirements/Component[@ID = current()/@ID]) = 0">
									<tr>
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:value-of select="@ID"/>
											<xsl:text>&#160;</xsl:text>
											<xsl:value-of select="@version"/>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printDependencies">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Dependencies">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Dependencies) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Dependencies) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Requirements/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Dependencies/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Dependencies">
			<br/>
			<table class="dependency">
				<thead>
					<tr>
						<th>
							<i>
								<font size="-1">Dependencies</font>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Dependencies/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Dependencies/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Dependencies/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Dependencies/Component[@ID = current()/@ID]) = 0">
									<tr>
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:value-of select="@ID"/>
											<xsl:text>&#160;</xsl:text>
											<xsl:value-of select="@version"/>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases/Release/Features">
		<xsl:if test="Feature">
			<table class="feature">
				<tbody>
					<xsl:for-each select="Feature[(not(@importance) or @importance &gt;= $importanceThreshold) and (not($typeFilter) or @type = $typeFilter)]">
						<tr>
							<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">even</xsl:when><xsl:otherwise>odd</xsl:otherwise></xsl:choose></xsl:attribute>
							<xsl:if test="@ID">
								<a>
									<xsl:attribute name="name"><xsl:value-of select="../../@version"/>_<xsl:value-of select="@ID"/></xsl:attribute>
								</a>
							</xsl:if>
							<td>
								<span>
									<xsl:attribute name="class"><xsl:text>featureVisibility</xsl:text><xsl:choose><xsl:when test="@importance"><xsl:value-of select="@importance"/></xsl:when><xsl:otherwise>4</xsl:otherwise></xsl:choose></xsl:attribute>
									<xsl:call-template name="_printFeatureIDInheritance"/>
									<xsl:if test="Abstract">
										<span class="featureSummary">
											<xsl:apply-templates select="Abstract"/>
										</span>
									</xsl:if>
									<xsl:for-each select="Item">
										<div class="item">
											<xsl:call-template name="_printContent"/>
										</div>
									</xsl:for-each>
									<xsl:call-template name="_printTypeWhyFix"/>
									<xsl:call-template name="_printAskingPersons"/>
									<xsl:call-template name="_printContributors"/>
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printAskingPersons">
		<xsl:if test="count(@askingPersonID | AskingPersons/AskingPerson/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>asking: </xsl:text>
					</font>
				</i>
				<span class="askingID">
					<xsl:for-each select="@askingPersonID | AskingPersons/AskingPerson/@ID">
						<xsl:value-of select="."/>
						<xsl:if test="position() != last()">, </xsl:if>
					</xsl:for-each>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printContributors">
		<xsl:if test="count(@contributorID | Contributors/Contributor/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>contributor: </xsl:text>
					</font>
				</i>
				<span class="contributorID">
					<xsl:for-each select="@contributorID | Contributors/Contributor/@ID">
						<xsl:value-of select="."/>
						<xsl:if test="position() != last()">, </xsl:if>
					</xsl:for-each>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printTypeWhyFix">
		<div align="right">
			<i>
				<font size="-1">
					<xsl:text>detail: </xsl:text>
				</font>
			</i>
			<span>
				<xsl:attribute name="class"><xsl:value-of select="@type"/>Type</xsl:attribute>
				<xsl:value-of select="@type"/>
				<xsl:text> </xsl:text>
			</span>
			<xsl:if test="@fixID">
				<span class="bug">
					<xsl:text>bug-fixing </xsl:text>
				</span>
			</xsl:if>
			<xsl:if test="@why">
				<span class="why">
					<xsl:value-of select="@why"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
			<xsl:if test="@category">
				<span class="category">
					<xsl:value-of select="@category"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
		</div>
	</xsl:template>
	<!--
	Outputs the exact name of the first version from which the documentation should be generated.
	The current node must be the 'ReleaseNotes/Releases' XML element.
	-->
	<xsl:template name="_printFirstVersionName">
		<xsl:choose>
			<xsl:when test="$firstVersion">
				<xsl:value-of select="$firstVersion"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Release[last()]/@version"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Same idea as the '_printFirstVersionName' template.
	-->
	<xsl:template name="_printLastVersionName">
		<xsl:choose>
			<xsl:when test="$lastVersion">
				<xsl:value-of select="$lastVersion"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Release[1]/@version"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Outputs the index (position) of the first version from which the documentation should be generated.
	The current node must be the 'ReleaseNotes/Releases' XML element.
	-->
	<xsl:template name="_printFirstVersionIndex">
		<xsl:variable name="actual_first_version">
			<xsl:call-template name="_printFirstVersionName"/>
		</xsl:variable>
		<xsl:for-each select="Release">
			<xsl:if test="@version = $actual_first_version">
				<xsl:value-of select="position()"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<!--
	Same idea as the '_printFirstVersionIndex' template.
	-->
	<xsl:template name="_printLastVersionIndex">
		<xsl:variable name="actual_last_version">
			<xsl:call-template name="_printLastVersionName"/>
		</xsl:variable>
		<xsl:for-each select="Release">
			<xsl:if test="@version = $actual_last_version">
				<xsl:value-of select="position()"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<!--
	This templates outputs the possible inheritance of a feature.
	The current node should be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printFeatureIDInheritance">
		<xsl:if test="@ID">
			<span class="visualNoPrint">
				<span class="featureID">
					<xsl:text>&lt;</xsl:text>
					<xsl:value-of select="@ID"/>
					<xsl:text>&gt;</xsl:text>
					<br/>
					<xsl:variable name="release_position" select="count(../../preceding-sibling::Release) + 1"/>
					<xsl:variable name="feature_id" select="@ID"/>
					<xsl:if test="../../../Release[position() &gt; $release_position and position() &lt;= $first_version_index and position() &gt;= $last_version_index]/Features/Feature[@ID = current()/@ID]">
						<font class="version" size="-2">
							<xsl:for-each select="../../../Release[position() &gt; $release_position and position() &lt;= $first_version_index and position() &gt;= $last_version_index]/Features/Feature[@ID = $feature_id]">
								<xsl:text>|</xsl:text>
								<br/>
								<xsl:text>+--</xsl:text>
								<a>
									<xsl:attribute name="href">#<xsl:value-of select="../../@version"/>_<xsl:value-of select="@ID"/></xsl:attribute>
									<xsl:text>[</xsl:text>
									<xsl:value-of select="../../@version"/>
									<xsl:text>]</xsl:text>
								</a>
								<br/>
							</xsl:for-each>
						</font>
					</xsl:if>
				</span>
			</span>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the version header part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseVersion">
		<div class="versionTitle">
			<span class="version">
				<xsl:value-of select="@version"/>
			</span>
		</div>
		<xsl:if test="@buildDate != ''">
			<div align="right">
				<i>
					<font size="-1">build date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@buildDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@deliveryDate != ''">
			<div align="right">
				<i>
					<font size="-1">delivery date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@deliveryDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@builderID != ''">
			<div align="right">
				<i>
					<font size="-1">builder: </font>
				</i>
				<span class="askingID">
					<xsl:value-of select="@builderID"/>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the content informative part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseContent">
		<div class="releaseSummary">
			<xsl:for-each select="Summary">
				<xsl:call-template name="_printContent"/>
			</xsl:for-each>
		</div>
		<br/>
		<xsl:apply-templates select="Features"/>
		<xsl:if test="$composition = 'true'">
			<xsl:call-template name="_printComposition"/>
		</xsl:if>
		<xsl:if test="$dependency = 'true'">
			<xsl:call-template name="_printDependencies"/>
		</xsl:if>
		<xsl:if test="$requirement = 'true'">
			<xsl:call-template name="_printRequirements"/>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the delivery end-part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseDelivery">
		<br/>
		<xsl:choose>
			<xsl:when test="Deliveries">
				<table class="delivery">
					<thead>
						<tr>
							<th>
								<i>
									<font size="-1">Deliveries</font>
								</i>
							</th>
						</tr>
					</thead>
					<tbody>
						<xsl:if test="Deliveries/Summary">
							<tr>
								<th colspan="2">
									<xsl:for-each select="Deliveries/Summary">
										<xsl:call-template name="_printContent"/>
									</xsl:for-each>
								</th>
							</tr>
						</xsl:if>
						<xsl:for-each select="Deliveries/Delivery">
							<tr>
								<td>
									<a>
										<xsl:attribute name="href"><xsl:if test="../../../../Deliveries/@href"><xsl:value-of select="../../../../Deliveries/@href"/><xsl:text>/</xsl:text></xsl:if><xsl:value-of select="@href"/></xsl:attribute>
										<xsl:value-of select="@href"/>
									</a>
								</td>
								<td>
									<xsl:call-template name="_printContent"/>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<table class="delivery">
					<thead>
						<tr>
							<th>
								<i>
									<font size="-1">No delivery</font>
								</i>
							</th>
						</tr>
					</thead>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Called when some content should be output.
	The current node must be of type 'xrn:contentType'.
	-->
	<xsl:template name="_printContent">
		<xsl:choose>
			<!--xsl:when test="not(text())"/-->
			<xsl:when test="@contentType = 'html'">
				<xsl:copy-of select="."/>
			</xsl:when>
			<xsl:when test="@contentType = 'process'">
				<!--Not possible for the moment, we'll see how to do that for better framework integration...-->
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
